# eric7.Plugins

Package containing all core plugins.

### Packages

AboutPlugin | Package containing the About plugin.
CheckerPlugins | Package containing the various core checker plugins.
DocumentationPlugins | Package containing the various core documentation tool plugins.
UiExtensionPlugins | Package containing the various interface extension plug-ins.
VcsPlugins | Package containing the various version control system plugins.
ViewManagerPlugins | Package containing the various view manager plugins.
WizardPlugins | Package containing the various core wizard plugins.

### Modules

PluginAbout | Module implementing the About plugin.
PluginCodeStyleChecker | Module implementing the code style checker plug-in.
PluginEricapi | Module implementing the Ericapi plugin.
PluginEricdoc | Module implementing the Ericdoc plugin.
PluginSyntaxChecker | Module implementing the Syntax Checker plugin.
PluginTranslator | Module implementing the Translator plugin.
PluginVcsGit | Module implementing the Git version control plugin.
PluginVcsMercurial | Module implementing the Mercurial version control plugin.
PluginVcsPySvn | Module implementing the PySvn version control plugin.
PluginVcsSubversion | Module implementing the Subversion version control plugin.
PluginVmListspace | Module implementing the Tabview view manager plugin.
PluginVmTabview | Module implementing the Tabview view manager plugin.
PluginWizardDotDesktop | Module implementing the .desktop wizard plug-in.
PluginWizardEricMessageBox | Module implementing the EricMessageBox wizard plugin.
PluginWizardEricPlugin | Module implementing the eric plug-in wizard plug-in.
PluginWizardPyRegExp | Module implementing the Python re wizard plugin.
PluginWizardQColorDialog | Module implementing the QColorDialog wizard plugin.
PluginWizardQFileDialog | Module implementing the QFileDialog wizard plugin.
PluginWizardQFontDialog | Module implementing the QFontDialog wizard plugin.
PluginWizardQInputDialog | Module implementing the QInputDialog wizard plugin.
PluginWizardQMessageBox | Module implementing the QMessageBox wizard plugin.
PluginWizardQRegularExpression | Module implementing the QRegularExpression wizard plugin.
PluginWizardSetup | Module implementing the setup.py wizard plug-in.